import logging
import coloredlogs 

def setup_logger(name, log_to_file=False, log_level=logging.DEBUG): 
    logger = logging.getLogger(name)
    logger.setLevel(log_level)

    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

    if log_to_file:
        file_handler = logging.FileHandler('app.log')
        file_handler.setLevel(log_level)
        file_handler.setFormatter(formatter)
        logger.addHandler(file_handler)

    console_handler = logging.StreamHandler()
    console_handler.setLevel(log_level)
    console_handler.setFormatter(formatter)
    logger.addHandler(console_handler)
    coloredlogs.install(level=log_level, logger=logger)
    return logger


from setuptools import setup, find_packages

setup(
    name='maglnuse_logging',
    version='1.2.0',
    packages=find_packages(),
    install_requires=[],
    tests_require=[],
    entry_points={},
    url='https://gitlab.com/adv_python_maglnuse/assignment3',
    license='MIT',
    author='maglnuse',
    author_email='n_maulen@kbtu.kz',
    description='A custom logging library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)